pub struct FloatingLabelProps {
pub label: String,
pub class: String,
pub children: Element,
/* private fields */
}Expand description
Bootstrap Floating Label wrapper.
Wraps an Input or Textarea with a floating label that moves above the control when focused or filled.
rsx! {
FloatingLabel { label: "Email address",
Input { r#type: "email", placeholder: "name@example.com" }
}
}Fields
label: StringLabel text.
class: StringAdditional CSS classes.
children: ElementChild element (Input or Textarea).
Implementations
Sourceimpl FloatingLabelProps
impl FloatingLabelProps
Sourcepub fn builder() -> FloatingLabelPropsBuilder<((), (), (), ())>
pub fn builder() -> FloatingLabelPropsBuilder<((), (), (), ())>
Create a builder for building FloatingLabelProps.
On the builder, call .label(...), .class(...)(optional), .attributes(...)(optional), .children(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of FloatingLabelProps.