pub enum TooltipPlacement {
Auto,
Top,
Bottom,
Start,
End,
}Expand description
Tooltip placement.
Variants
Auto
Choose the first fallback placement that fits the viewport.
Top
Place tooltip above the trigger.
Bottom
Place tooltip below the trigger.
Start
Place tooltip before the trigger in the inline axis.
End
Place tooltip after the trigger in the inline axis.