pub struct DropdownMenuProps {
pub show: bool,
pub align_end: bool,
pub class: String,
pub children: Element,
/* private fields */
}Expand description
Standalone Bootstrap dropdown menu.
Use this when open/position behavior is owned by a surrounding component but the menu and items should still use Bootstrap dropdown structure.
Fields
show: boolWhether to show the menu.
align_end: boolAlign menu to the end side.
class: StringAdditional CSS classes.
children: ElementChild menu items.
Implementations
Sourceimpl DropdownMenuProps
impl DropdownMenuProps
Sourcepub fn builder() -> DropdownMenuPropsBuilder<((), (), (), (), ())>
pub fn builder() -> DropdownMenuPropsBuilder<((), (), (), (), ())>
Create a builder for building DropdownMenuProps.
On the builder, call .show(...)(optional), .align_end(...)(optional), .class(...)(optional), .attributes(...)(optional), .children(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of DropdownMenuProps.